===
ytu
===


.. image:: https://img.shields.io/pypi/v/ytu.svg
        :target: https://pypi.python.org/pypi/ytu

.. image:: https://img.shields.io/travis/yaph/ytu.svg
        :target: https://travis-ci.org/yaph/ytu



A library to extract information from YouTube URLs. Currently provides the function `video_id` to retrieve the video ID from a YouTube URL.


Usage
-----

::

        import ytu

        url = 'https://www.youtube.com/watch?v=dQw4w9WgXcQ'
        if ytu.is_youtube(url):
            print(ytu.video_id(url))


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
